@@ -9,6 +9,7 @@ import warnings
 import inspect
 from abc import ABCMeta
 from collections import OrderedDict, namedtuple
+import textwrap
 
 import numpy as np
 import matplotlib.pyplot as plt
@@ -21,6 +22,7 @@ from astropy.coordinates import SkyCoord, UnitSphericalRepresentation
 
 import sunpy.io as io
 import sunpy.coordinates
+import sunpy.cm
 from sunpy.util.decorators import deprecated
 from sunpy import config
 from sunpy.extern import six
@@ -233,32 +235,31 @@ class GenericMap(NDData):
             " coordinate is not yet implemented.")
 
     def __repr__(self):
-        return (
-"""SunPy Map
----------
-Observatory:\t\t {obs}
-Instrument:\t\t {inst}
-Detector:\t\t {det}
-Measurement:\t\t {meas}
-Wavelength:\t\t {wave}
-Observation Date:\t {date:{tmf}}
-Exposure Time:\t\t {dt:f}
-Dimension:\t\t {dim}
-Coordinate System:\t {coord.name}
-Scale:\t\t\t {scale}
-Reference Pixel:\t {refpix}
-Reference Coord:\t {refcoord}
-
-""".format(obs=self.observatory, inst=self.instrument, det=self.detector,
-           meas=self.measurement, wave=self.wavelength, date=self.date,
-           dt=self.exposure_time,
-           dim=u.Quantity(self.dimensions),
-           scale=u.Quantity(self.scale),
-           coord=self.coordinate_frame,
-           refpix=u.Quantity(self.reference_pixel),
-           refcoord=u.Quantity((self.reference_coordinate.data.lon,
-                                self.reference_coordinate.data.lat)),
-           tmf=TIME_FORMAT) + self.data.__repr__())
+        return textwrap.dedent("""\
+                   SunPy Map
+                   ---------
+                   Observatory:\t\t {obs}
+                   Instrument:\t\t {inst}
+                   Detector:\t\t {det}
+                   Measurement:\t\t {meas}
+                   Wavelength:\t\t {wave}
+                   Observation Date:\t {date:{tmf}}
+                   Exposure Time:\t\t {dt:f}
+                   Dimension:\t\t {dim}
+                   Coordinate System:\t {coord.name}
+                   Scale:\t\t\t {scale}
+                   Reference Pixel:\t {refpix}
+                   Reference Coord:\t {refcoord}
+                   """).format(obs=self.observatory, inst=self.instrument, det=self.detector,
+                               meas=self.measurement, wave=self.wavelength, date=self.date,
+                               dt=self.exposure_time,
+                               dim=u.Quantity(self.dimensions),
+                               scale=u.Quantity(self.scale),
+                               coord=self.coordinate_frame,
+                               refpix=u.Quantity(self.reference_pixel),
+                               refcoord=u.Quantity((self.reference_coordinate.data.lon,
+                                                    self.reference_coordinate.data.lat)),
+                               tmf=TIME_FORMAT) + self.data.__repr__()
 
     @classmethod
     def _new_instance(cls, data, meta, plot_settings=None, **kwargs):
